%define pyname  Shiboken6

%define qttarballdir pyside-setup-everywhere-src

%define toolchain clang

Name:           shiboken6
Version:        6.7.2
Release:        %mkrel 1
License:        LGPLv2+
Summary:        Creates the PySide6 bindings source files for Qt6
Group:          Development/KDE and Qt
URL:            https://wiki.qt.io/Qt_for_Python
Source0:        https://download.qt.io/official_releases/QtForPython/pyside6/PySide6-%{version}-src/%{qttarballdir}-%{version}.tar.xz
# From opensuse
Patch0:         0001-Always-link-to-python-libraries.patch
# Upstream patches

BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  cmake(Qt6Test)

BuildRequires:  pkgconfig(python3)
BuildRequires:  python3-setuptools
BuildRequires:  python3-sphinx
BuildRequires:  python3-numpy-devel
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(libxml-2.0)

BuildRequires:  clang-devel
BuildRequires:  llvm-devel >= 17.0.6-6

Requires:       python3-%{name} = %{version}-%{release}

### Python 3

%description
The Shiboken6 Generator (A.K.A. shiboken) is the plugin that creates the
PySide6 bindings source files from Qt6 headers and auxiliary files
(type systems, global.h and glue files).

%files
%{_bindir}/%{name}
%{_bindir}/shiboken_tool.py

#------------------------------------------------------------------------------

%package -n     python3-%{name}
Summary:        Creates the Python3 PySide6 bindings source files for Qt6
Group:          Development/KDE and Qt

%description -n python3-%{name}
The Shiboken6 Generator (A.K.A. shiboken) is the plugin that creates the
Python3 PySide6 bindings source files from Qt6 headers and auxiliary files
(type systems, global.h and glue files).

%files -n python3-%{name}
%{python3_sitearch}/%{name}/
%{python3_sitearch}/%{name}-%{version}-py%{python3_version}.egg-info/
%{python3_sitearch}/%{name}_generator/
%{python3_sitearch}/%{name}_generator-%{version}-py%{python3_version}.egg-info/

#------------------------------------------------------------------------------

%define py3major   6.7
%define py3libname %mklibname %{name}-abi3_ %{py3major}

%package -n     %{py3libname}
Summary:        Shiboken6 Generator core library
Group:          System/Libraries

%description -n %{py3libname}
Python3 Shiboken6 Generator core library.

%files -n %{py3libname}
%{_libdir}/lib%{name}.abi3.so.%{py3major}{,.*}

#------------------------------------------------------------------------------

%define py3libname_dev %mklibname %{name} -d

%package -n     %{py3libname_dev}
Summary:        Development files for Python3 Shiboken6 Generator
Group:          Development/KDE and Qt
Requires:       %{name} = %{version}-%{release}
Requires:       %{py3libname} = %{version}-%{release}
Requires:       python3-%{name} = %{version}-%{release}
Requires:       clang-devel
Requires:       llvm-devel
Provides:       %{name}-devel = %{version}-%{release}
Provides:       %{_lib}%{name}-python%{python3_version}-devel = %{version}-%{release}

%description -n %{py3libname_dev}
Development files for Python3 Shiboken6 Generator.

%files -n %{py3libname_dev}
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.abi3.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/Shiboken6Tools/
%{_libdir}/cmake/Shiboken6/

### End of Python 3
#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n %{qttarballdir}-%{version}

# Fix installation dir
sed -i 's#purelib#platlib#' sources/shiboken6/cmake/ShibokenHelpers.cmake

%build
export CLANG_INSTALL_DIR="%{_prefix}"

%global _vpath_srcdir sources/shiboken6
%cmake_qt6 \
  -DBUILD_TESTS:BOOL=ON \
  -DPYTHON_EXECUTABLE:STRING=python3 \
  -DNUMPY_INCLUDE_DIR:STRING=%{python_sitearch}/numpy/core/include \
  -DCMAKE_SKIP_RPATH:BOOL=ON \
  -DQFP_NO_STRIP:BOOL=ON
%cmake_build

%install
%cmake_install

#
# Generate egg-info manually and install since we're performing a cmake build.
#
# Copy CMake configuration files from the BINARY dir back to the SOURCE dir so
# setuptools can find them.
cp %{_vpath_builddir}/shibokenmodule/{*.py,*.txt} sources/shiboken6/shibokenmodule/
%{__python3} setup.py egg_info
for name in shiboken6 shiboken6_generator; do
  mkdir -p %{buildroot}%{python3_sitearch}/$name-%{version}-py%{python3_version}.egg-info
  cp -p $name.egg-info/{PKG-INFO,not-zip-safe,top_level.txt} \
        %{buildroot}%{python3_sitearch}/$name-%{version}-py%{python3_version}.egg-info/
done

# Python shebang
%py3_shebang_fix %{buildroot}%{_bindir}/*

%check
# the pyside tests need to know the path to the 'qmake' executable
export PATH=%{_qt6_bindir}:$PATH

# Needed by the shiboken tests
export LD_LIBRARY_PATH=%{buildroot}%{_qt6_libdir}:$LD_LIBRARY_PATH
# Since we need CMAKE_SKIP_RPATH to avoid having bogus RUNPATH in the shiboken libraries,
# It needs to know the path to a couple tests folders
for dir in libminimal libother libsample libsmart; do
  export LD_LIBRARY_PATH=$PWD/sources/shiboken6/tests/$dir:$LD_LIBRARY_PATH
done

pushd sources/shiboken6
%{?xvfb_command}
ctest \
  --output-on-failure \
  --force-new-ctest-process \
  --test-dir . \
  --parallel %{_smp_build_ncpus} \
  --debug \
  %{?excluded_tests:--exclude-regex "($ctest_exclude_regex)"}
popd


%changelog
* Thu Aug 01 2024 daviddavid <daviddavid> 6.7.2-1.mga10
+ Revision: 2083327
- New version 6.7.2

* Tue Jun 11 2024 daviddavid <daviddavid> 6.7.1-2.mga10
+ Revision: 2072576
- rebuild for 'Qt_$MAJOR_PRIVATE_API' settings

* Sun May 26 2024 daviddavid <daviddavid> 6.7.1-1.mga10
+ Revision: 2067700
- New version 6.7.1
+ wally <wally>
- drop i586 sse2 hack as we don't support i586 anymore
- build using clang toolchain

* Mon Apr 01 2024 wally <wally> 6.6.2-3.mga10
+ Revision: 2053721
- rebuild for armv7hl with armhf enabled llvm

* Sun Mar 31 2024 wally <wally> 6.6.2-2.mga10
+ Revision: 2053454
- build with sse2 on ix86
+ daviddavid <daviddavid>
- rebuild for new llvm/clang 17

* Sat Feb 17 2024 daviddavid <daviddavid> 6.6.2-1.mga10
+ Revision: 2042205
- New version 6.6.2

* Fri Dec 08 2023 daviddavid <daviddavid> 6.6.0-2.mga10
+ Revision: 2015600
- rebuild for py3.12

* Sat Oct 21 2023 daviddavid <daviddavid> 6.6.0-1.mga10
+ Revision: 1999941
- New version 6.6.0

* Thu Sep 21 2023 daviddavid <daviddavid> 6.5.2-1.mga10
+ Revision: 1989197
- new version: 6.5.2
- remove merged upstream patch

* Tue Feb 07 2023 daviddavid <daviddavid> 6.4.1-4.mga9
+ Revision: 1939347
- generate egg-info manually and install since we're performing a cmake build

* Sat Dec 24 2022 daviddavid <daviddavid> 6.4.1-3.mga9
+ Revision: 1926247
- rebuild for core/release

* Fri Dec 23 2022 daviddavid <daviddavid> 6.4.1-2.mga9
+ Revision: 1926219
- add upstream patch to fix a cmake-only build (PYSIDE-2127)

* Fri Dec 23 2022 daviddavid <daviddavid> 6.4.1-1.mga9
+ Revision: 1926214
- New version 6.4.1
- library was renamed upstream to lib*.abi3.so
- rename also devel sub pkg

* Fri Oct 28 2022 papoteur <papoteur> 6.4.0-1.mga9
+ Revision: 1899944
- new 6.4.0, forked from shiboken2

* Thu Sep 22 2022 tv <tv> 5.15.6-2.mga9
+ Revision: 1891444
- Rebuild for llvm-15

* Wed Sep 07 2022 papoteur <papoteur> 5.15.6-1.mga9
+ Revision: 1885489
- new 5.15.6

* Sat Apr 02 2022 tv <tv> 5.15.2.1-2.mga9
+ Revision: 1840364
- Rebuild for llvm-14

* Thu Feb 17 2022 akien <akien> 5.15.2.1-1.mga9
+ Revision: 1779055
- Version 5.15.2.1, fixes python 3.10 support
+ tv <tv>
- Rebuild for python-3.10

* Thu Oct 21 2021 tv <tv> 5.15.2-4.mga9
+ Revision: 1752512
- Rebuild for llvm 13.0

* Wed Mar 17 2021 daviddavid <daviddavid> 5.15.2-3.mga9
+ Revision: 1703995
- rebuild for python 3.9

* Mon Mar 01 2021 tv <tv> 5.15.2-2.mga9
+ Revision: 1695524
- rebuild for llvm/clang-12

* Sat Dec 05 2020 daviddavid <daviddavid> 5.15.2-1.mga8
+ Revision: 1652917
- New version 5.15.2

* Thu Nov 26 2020 tv <tv> 5.15.1-2.mga8
+ Revision: 1649617
- rebuild for llvm/clang 11.0

* Sat Sep 12 2020 daviddavid <daviddavid> 5.15.1-1.mga8
+ Revision: 1625260
- New version 5.15.1

* Thu Jun 04 2020 daviddavid <daviddavid> 5.15.0-1.mga8
+ Revision: 1590420
- New version 5.15.0

* Sun Mar 22 2020 tv <tv> 5.14.1-3.mga8
+ Revision: 1558875
- rebuild for llvm-10.0.0

* Thu Feb 20 2020 umeabot <umeabot> 5.14.1-2.mga8
+ Revision: 1545942
- Mageia 8 Mass Rebuild

* Thu Jan 30 2020 daviddavid <daviddavid> 5.14.1-1.mga8
+ Revision: 1485558
- New version 5.14.1

* Thu Jan 30 2020 daviddavid <daviddavid> 5.14.0-1.mga8
+ Revision: 1485475
- New version 5.14.0
+ wally <wally>
- build with new cmake macros

* Tue Sep 17 2019 tv <tv> 5.13.1-2.mga8
+ Revision: 1443080
- rebuild for clang-9.0

* Sun Sep 15 2019 daviddavid <daviddavid> 5.13.1-1.mga8
+ Revision: 1440995
- New version 5.13.1
- Remove merged upstream patch

* Sat Aug 03 2019 daviddavid <daviddavid> 5.13.0-2.mga8
+ Revision: 1427001
- add upstream patch to fix qApp import of QCoreApplication

* Sat Jul 27 2019 daviddavid <daviddavid> 5.13.0-1.mga8
+ Revision: 1424520
- New version 5.13.0
- Now libmajor is 5.13

* Mon Apr 15 2019 daviddavid <daviddavid> 5.12.2-4.mga7
+ Revision: 1390767
- rebuild for new llvm/clang 8.0

* Sun Apr 07 2019 daviddavid <daviddavid> 5.12.2-3.mga7
+ Revision: 1386673
- devel pkg require clang-devel and llvm-devel

* Sun Apr 07 2019 daviddavid <daviddavid> 5.12.2-2.mga7
+ Revision: 1386649
- devel pkg require main pkg for /usr/bin/shiboken2

* Sun Apr 07 2019 daviddavid <daviddavid> 5.12.2-1.mga7
+ Revision: 1386637
- add patch to fix Python3 linking issue
- initial package shiboken2

